==> pangle_flutter-1.9.3.tar.gz: lib/pangle_flutter.dart <==
/*
 * Copyright (c) 2021 nullptrX
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

library pangle_flutter;

export 'src/banner/bannerview_android.dart';
export 'src/bannerview.dart';
export 'src/build.dart';
export 'src/config_android.dart';
export 'src/config_ios.dart';
export 'src/constant.dart';
export 'src/feed/feedview_android.dart';
export 'src/feedview.dart';
export 'src/model.dart';
export 'src/pangle_plugin.dart';
export 'src/size.dart';
export 'src/splash/splashview_android.dart';
export 'src/splashview.dart';
export 'src/util.dart';

==> pangle_flutter-2.0.1.tar.gz: lib/pangle_flutter.dart <==
/*
 * Copyright (c) 2021 nullptrX
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

library pangle_flutter;

export 'src/build.dart';
export 'src/config_android.dart';
export 'src/config_ios.dart';
export 'src/constant.dart';
export 'src/model.dart';
export 'src/pangle_plugin.dart';
export 'src/size.dart';
export 'src/util.dart';
export 'src/view/banner/bannerview_android.dart';
export 'src/view/banner/bannerview_android_legacy.dart';
export 'src/view/bannerview.dart';
export 'src/view/feed/feedview_android.dart';
export 'src/view/feed/feedview_android_legacy.dart';
export 'src/view/feedview.dart';
export 'src/view/splash/splashview_android.dart';
export 'src/view/splash/splashview_android_legacy.dart';
export 'src/view/splashview.dart';
